@@ -197,7 +197,7 @@ bq_check_response <- function(status, type, content) {
 
 signal_reason <- function(reason, message) {
   if (is.null(reason)) {
-    rlang::abort(message)
+    abort(message)
   } else {
     advice <- NULL
     if (reason == "responseTooLarge") {
@@ -220,7 +220,7 @@ signal_reason <- function(reason, message) {
       i = advice
     )
 
-    rlang::abort(message, class = paste0("bigrquery_", reason))
+    abort(message, class = paste0("bigrquery_", reason))
   }
 }
 
